pub struct AddrEntryIter<R: Reader> {
input: R,
encoding: Encoding,
}Expand description
An iterator over the addresses from a .debug_addr section.
Can be used with
FallibleIterator.
Fields
input: Rencoding: EncodingImplementations
Sourceimpl<R: Reader> AddrEntryIter<R>
impl<R: Reader> AddrEntryIter<R>
Sourcepub fn next(&mut self) -> Result<Option<u64>>
pub fn next(&mut self) -> Result<Option<u64>>
Advance the iterator and return the next address.
Returns the newly parsed address as Ok(Some(addr)). Returns Ok(None)
when iteration is complete and all addresses have already been parsed and
yielded. If an error occurs while parsing the next address, then this error
is returned as Err(e), and all subsequent calls return Ok(None).